<?php
/*
Plugin Name: KeywordLuv
Plugin URI: http://www.scratch99.com/wordpress-plugin-keywordluv/
Description: Reward your commentators by separating their name from their keywords, in the link to their website, giving them improved anchor text. For example, leaving "Stephen @ Custom WordPress Plugins" in the name field, will result in the following: Stephen from <a href="http://www.scratch99.com/">Custom WordPress Plugins</a>. Requires a <a href="http://andybeard.eu/2007/02/ultimate-list-of-dofollow-plugins-banish-nofollow-from-comments-and-trackbacks.html">DoFollow plugin</a> to be effective.
Version: 1.03
Date: 7th April 2008
Author: Stephen Cronin
Author URI: http://www.scratch99.com/
   
   Copyright 2008  Stephen Cronin  (email : sjc@scratch99.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/ 

// ****** GLOBAL VARIABLES AND CONSTANTS ******
$keywordluv_options = get_option('keywordluv_options');
$keywordluv_name = '';
define('KEYWORDLUV_VERSION', '1.03');
define('KEYWORDLUV_DATE', '7th April 2008');
define('KEYWORDLUV_PATH', get_settings('siteurl') . '/wp-content/plugins/' . dirname(plugin_basename(__FILE__)));
// *******************************************

// ****** SETUP ACTIONS AND FILTERS ******
add_action('activate_' . dirname(plugin_basename(__FILE__)) . '/' . basename(__FILE__), 'create_keywordluv_options');
add_filter( 'get_comment_author_link', 'keywordluv');
add_filter( 'get_comment_author', 'keywordluv2');
add_action('comment_form','keywordluv_text');
add_action('admin_menu', 'keywordluv_admin');
add_filter('preprocess_comment','keywordluv_commentluv',10);  // low priority so CommentLuv fires first
// **************************************

// ****** FOR THEMES THAT DON'T USE COMMENT_AUTHOR_LINK ******
function keywordluv_name() {
	global $keywordluv_options;
	// only want to do anything if compatibility mode is on
	if ($keywordluv_options['compatibility_mode']=='true') {
		global $keywordluv_name;
		echo $keywordluv_name;
	}
}
// ***********************************************************

// ****** FUNCTION TO STRIP THE KEYWORDS OUT FOR COMMENTLUV ******
function keywordluv_commentluv($comment_data) {
	$author = $comment_data['comment_author'];
	$end = strpos($author, "@");
	if ($end != 0) {
		$comment = $comment_data['comment_content'];
		if (strstr($comment,$author)) {
			$comment_data['comment_content'] = str_replace($author,trim(substr($author,0,$end)),$comment);
		}
	}
	return $comment_data;
}
// ***************************************************************

// ****** FUNCTION TO MOVE NAME OUTSIDE THE LINK ******
function keywordluv($link) {
	global $keywordluv_options;
	if ($keywordluv_options['compatibility_mode']=='true') {
		global $keywordluv_name;
		// if it's empty then keywordluv2 didn't find @.
		if ($keywordluv_name != '') {
			$link = $keywordluv_name . $link;
		}
	}
	else {
		// only do anything if @ is present in anchor text.
		$end = strpos($link, "@");
		if ($end != 0) {
			$start = strpos($link, ">")+1;
			$name = trim(substr($link,$start,$end-$start));
			$rest = substr($link,0,$start) . ltrim(substr($link,$end+1));
			$link = $name . ' from ' . $rest;
		}
	}
	return $link;
}
// ***************************************************

// ****** FUNCTION TO MOVE NAME OUTSIDE THE LINK ******
function keywordluv2($author) {
	global $keywordluv_options;
	// only filter comment_author if compatibility mode is on, as it affects Admin->Comments
	if ($keywordluv_options['compatibility_mode']=='true') {
		global $keywordluv_name;
		// only do anything if @ is present in anchor text.
		$end = strpos($author, "@");
		if ($end != 0) {
			$keywordluv_name = trim(substr($author,0,$end)) . ' from ';
			$author = ltrim(substr($author,$end+1));
		}
		else {
			$keywordluv_name = '';
		}
	}
	return $author;
}
// ***************************************************

// ****** FUNCTION TO ADD INFORMATION TO COMMENT FORM ******
function keywordluv_text($id){
	global $user_ID, $keywordluv_options;
	if ($keywordluv_options['show_message']=='true') {
		if (!$user_ID) {
			echo '<p>'.$keywordluv_options['message'].'</p>';
		}
	}
	return $id;
}
// **********************************************************

// ****** FUNCTION TO CREATE OPTIONS AND DEFAULTS ON ACTIVATION ******
function create_keywordluv_options() {
	// get current options, assign defaults if not already set, update the options db
	global $keywordluv_options;
	$message = 'This site uses <a href="http://www.scratch99.com/wordpress-plugin-keywordluv/">KeywordLuv</a>. Enter YourName@YourKeywords in the Name field to take advantage.';
	if (!isset($keywordluv_options['show_message'])){ $keywordluv_options['show_message'] = 'true';}
	if (!isset($keywordluv_options['message'])){ $keywordluv_options['message'] = $message;}
	if (!isset($keywordluv_options['compatibility_mode'])){ $keywordluv_options['compatibility_mode'] = 'false';}
	$keywordluv_options['default_message'] = $message;
	update_option('keywordluv_options', $keywordluv_options);
}
// ******************************************************************

// ****** FUNCTION TO ADD ADMIN PAGE TO PRESENTATION MENU ******
function keywordluv_admin() {
	if (function_exists('add_options_page')) {
		add_options_page('KeywordLuv Setup', 'KeywordLuv', 10, basename(__FILE__), 'keywordluv_admin_page');
	}
}
// ************************************************************

// ****** FUNCTION TO DRAW OPTIONS PAGE CONTENT ******
function keywordluv_admin_page() {

	// declare globals so we have access to them
	global $keywordluv_options;
	
	// Post the form
	if (isset($_POST['keywordluv_options_submit'])) {
		if ($_POST['keywordluv_show_message']=='true') {$keywordluv_options['show_message'] = 'true';} else {$keywordluv_options['show_message'] = 'false';} 
		$keywordluv_options['message'] = trim(stripslashes($_POST['keywordluv_message']));
		if ($_POST['keywordluv_compatibility_mode']=='true') {$keywordluv_options['compatibility_mode'] = 'true';} else {$keywordluv_options['compatibility_mode'] = 'false';} 
		update_option('keywordluv_options', $keywordluv_options);
		echo '<div id="message" class="updated fade"><p><strong>';
		_e('Options saved.');
		echo '</strong></p></div>';
	} 

	// now drop out of php to create the HTML for the Options page
?>
	<div class="wrap">
	<h2>KeywordLuv Information</h2>

	<script language = "javascript">	
		// function to send ajax call to get version from server 
		function scratch99_servercall() {
			// Generate the request object 
			if (window.XMLHttpRequest) { 	// Mozilla & other compliant browsers
				scratch99_request = new XMLHttpRequest();
			} else if (window.ActiveXObject) { 	// Internet Explorer
				scratch99_request = new ActiveXObject("Microsoft.XMLHTTP");
			}
			// If we couldn't create a request object, error out.
			if (!scratch99_request) {
				alert('Browser does not support AJAX!');
				return false;
			}
			// Open the connection, set where response will go and send request.
			scratch99_request.open('GET', '<?php echo KEYWORDLUV_PATH; ?>/versioncheck.php?appname=keywordluv&version=<?php echo KEYWORDLUV_VERSION; ?>', true);
			var scratch99_version = document.getElementById("scratch99_version");
			scratch99_request.onreadystatechange = function() {
				if (scratch99_request.readyState == 4 && scratch99_request.status == 200) {
					scratch99_version.innerHTML = scratch99_request.responseText;
				}
			}
			scratch99_request.send(null);
		}
		// function to reset box to default
		function keywordluv_reset() {
			var keywordluv_message = document.getElementById("keywordluv_message");
			keywordluv_message.value = '<?php echo $keywordluv_options['default_message']; ?>';
		}
	  </script>
	
	<!-- Show Version information, create span to put ajax call return and create Check for Update button -->
	<strong>Version:</strong><?php echo KEYWORDLUV_VERSION . ' (' . KEYWORDLUV_DATE . ')'; ?> 
	<span id="scratch99_version">
	<noscript><span style="background:#444444; padding:2px; color:#FFFFFF"><strong>Javascript must be enabled to check for updates</strong></span></noscript>
	</span> 
	<div class="submit" style="text-align: left"><input type="button" id="scratch99_update_button" name="scratch99_update_button" onClick="scratch99_servercall()" value="<?php _e('Check For Update &raquo;') ?>" /></div>
	</div>

	<div class="wrap">
	<h2>KeywordLuv Settings</h2>
	<form name="keywordluv_options_form" action="<?php echo $_SERVER['PHP_SELF'] . '?page=' . basename(__FILE__); ?>" method="post">
	<div class="submit" style="float:right">
	<input type="submit" name="keywordluv_options_submit" value="<?php _e('Update Options &raquo;') ?>"/>
	</div>
	
	<strong>Comment Form Message</strong>: <br />
	<textarea style="width: 75%; height: 90px;" id="keywordluv_message" name="keywordluv_message"><?php echo $keywordluv_options['message']; ?></textarea>
	<br />
	This message will be shown on the comment form, if the Show Comment Form Message options is set.<br />
	<input type="button" id="keywordluv_reset_button" name="keywordluv_reset_button" onClick="keywordluv_reset()" value="Reset To Default" />
	<br /><br /><br />

	<strong>Show Comment Form Message</strong>: <br /><br />
	<input type="checkbox" name="keywordluv_show_message" id="keywordluv_show_message" value="true" <?php if ($keywordluv_options['show_message']=='true') {echo 'checked="checked"';}?> /> Turn this off if you want to tell your visitors how to enter name @ keywords through your theme, rather than this message.
	<br /><br />

	<strong>Compatibility Mode</strong>: <br /><br />
	<input type="checkbox" name="keywordluv_compatibility_mode" id="keywordluv_compatibility_mode" value="true" <?php if ($keywordluv_options['compatibility_mode']=='true') {echo 'checked="checked"';}?> /> Turn this on if your theme is not compatible with KeywordLuv. <strong>Warning: <a href="http://www.scratch99.com/wordpress-plugin-keywordluv/keywordluv-theme-compatibility-issue/">Read the implications</a> of doing this first</strong>.
	<br /><br />

	<!-- End Form -->
	</form>
	<div style="clear:both"></div>
	</div>
	
	<!-- Thank You Section -->
	<div class="wrap">
	<p>Thank you for using the KeywordLuv plugin. If you like it, please link to the <a href="http://www.scratch99.com/wordpress-plugin-keywordluv/"><strong>KeywordLuv home page</strong></a> so others can find out about it and/or make a donation via the home page.</p>
	<div style="font-size:0.9em">KeywordLuv Copyright 2008 by Stephen Cronin. Released under the GNU General Public License (version 2 or later).</div>
	</div>
	
<?php
}
// *********** END ADMIN PAGE FUNCTION ***********


?>